<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Realestate
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function realestate_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function realestate_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function realestate_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function realestate_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function realestate_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = realestate()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Realestate_Sanitize::background( realestate_get_settings( 'theme_background' ) );

	// Header Background.
	if ( ! realestate_get_settings( 'header_slider' ) || ! is_page_template( 'page-home.php' ) ) {
		$css['global']['#site-header'] = Realestate_Sanitize::background( realestate_get_settings( 'header_background' ) );
	}
	if ( 'header-layout2' === realestate_get_settings( 'header_styles' ) ) {
		$css['global']['#site-header.header-layout2'] = Realestate_Sanitize::background( realestate_get_settings( 'header_layout2_background' ) );
	}

	// Logo Font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'realestate_logo' ) ) );
	// Primary Navigation font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'content_font' ) ) );
	// Pagination.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'pagination_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'loadmore_font' ) ) );
	// Archive Pages font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_post_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_post_excerpt_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_meta_info_font' ) ) );
	// Single post title font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_title_font' ) ) );
	// Single post author info font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_subscribe_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_subscribe_text_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_subscribe_input_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_subscribe_submit_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'authorbox_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'authorbox_author_name_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'authorbox_text_font' ) ) );
	// Footer Nav.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_buttons_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'submit_button_font' ) ) );
	// Sidebar widget font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'mts_widget_links' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'default_widget_links' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_url_bigthumb' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_font_bigthumb' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_postinfo_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'sidebar_postinfo_font_bigthumb' ) ) );
	// Tab widget title font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'tabs_title_font' ) ) );
	// Footer widget title font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'top_footer_link_font' ) ) );
	// Footer MTS link font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'mts_footer_widget_links' ) ) );
	// Footer widget font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'top_footer_font' ) ) );
	// Copyrights section font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Realestate_Sanitize::background( realestate_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Realestate_Sanitize::background( realestate_get_settings( 'mts_copyrights_background' ) );

	realestate_dynamic_css_skin( $css );
	realestate_sidebar_position( $css );
	realestate_header( $css );
	realestate_header_slider( $css );
	realestate_sidebar_styling( $css );
	realestate_home_sections( $css );
	realestate_page_titles( $css );
	realestate_post_layouts( $css );
	realestate_post_pagination( $css );
	realestate_footer( $css );
	realestate_copyrights( $css );
	realestate_single( $css );
	realestate_single_social_buttons( $css );
	realestate_archive_post( $css );
	realestate_misc_css( $css );
	realestate_wprep_sections( $css );

	return apply_filters( 'realestate_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme = Realestate_Sanitize::color( realestate_get_settings( 'primary_color_scheme' ) );
	$hover_color_scheme   = Realestate_Sanitize::color( realestate_get_settings( 'hover_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'blockquote',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'.widget .wp_review_tab_widget_content a',
		'.sidebar .wpt_widget_content a',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'.related-readmore a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget .sbutton',
		'.shareit-circular.standard .share-text',
		'.breadcrumb a',
		'.rank-math-breadcrumb a',
		'.about-section .quote::before',
		'.widget.widget_categories li span',
		'.reply a',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.shareit-circular.standard .fa:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-default .latestPost .post-info a:hover',
		'.layout-grid .latestPost .title a:hover',
		'.layout-grid .latestPost .post-info a:hover',
		'.single-postinfo-wrapper .post-info a:hover',
		'#sidebar .widget li a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'.aboutme-widget .aboutme-social a:hover',
		'.layout-default .post-info .fa',
		'.single-featured-content .post-info .fa',
		'.woocommerce ul.products li.product .woocommerce-loop-product__title:hover',
	);

	$css['global'][ realestate_implode( $elements ) ]['color'] = $primary_color_scheme;
	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
	);
	$css['global'][ realestate_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.mobile-menu-active .navigation.mobile-menu-wrapper',
		'blockquote::before',
		'.button',
		'.readMore a',
		'.widget #wp-subscribe input.submit',
		'.instagram-button a',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'.f-widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.f-widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.f-widget .widget #wp-subscribe input.submit:hover',
		'.f-widget .button:hover',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.heading::before',
		'.top-heading::before',
		'.single-full-header .single-title::before',
		'.single-full-header .breadcrumb::before',
		'.single-full-header .rank-math-breadcrumb::before',
		'.tags a:hover',
		'#sidebar .widget .tagcloud a:hover',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.footer-widgets .f-widget .tagcloud a',
		'.footer-widgets .f-widget .widget .wpt_widget_content #tags-tab-content ul li a',
		'.postauthor h5::before',
		'.single-subscribe .widget #wp-subscribe input.consent-field::after',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.woocommerce a.button',
		'.woocommerce button.button',
		'.woocommerce input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce-page a.button',
		'.woocommerce-page button.button',
		'.woocommerce-page input.button',
		'.woocommerce-page #respond input#submit',
		'.woocommerce-page #content input.button',
		'.woocommerce-page .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce div.product form.cart .button',
		'.woocommerce-page div.product form.cart .button',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.woocommerce a.checkout-button.button',
	);

	$css['global'][ realestate_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper'] = Realestate_Sanitize::background( realestate_get_settings( 'nav_background' ) );

	// Background Color Important.
	$elements = array(
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ realestate_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget #s:focus',
		'.single-subscribe .widget #wp-subscribe .title',
	);

	$css['global'][ realestate_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Hover text Color.
	$hover_elements = array(
		'.widget #wp-subscribe input.submit:hover',
		'.toggle-menu .toggle-caret .fa',
		'.widget.social-profile-icons a:hover',
		'.widget .sbutton:hover',
		'.related-posts .post-info a:hover',
	);

	$css['global'][ realestate_implode( $hover_elements ) ]['color'] = $hover_color_scheme;

	// Hover background Color.
	$hover_elements = array(
		'.sticky-tag',
		'.owl-prev',
		'.owl-next',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.button:hover',
		'.readMore a:hover',
		'.instagram-button a:hover',
		'.widget #wp-subscribe input.submit:hover',
		'.f-widget .tagcloud a:hover',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt:hover',
		'.woocommerce button.button.alt:hover',
		'.woocommerce input.button.alt:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce div.product form.cart .button:hover',
	);

	$css['global'][ realestate_implode( $hover_elements ) ]['background-color'] = $hover_color_scheme;

	// WP Real Estate text Color.
	$elements = array(
		'.wre-view-switcher > div i',
		'.ext-features i',
		'.int-features i',
		'.wre-single .mls-wrapper',
		'.wre-widget .contact li i',
		'body.single-agency .wre-single .tagline',
		'.wre ul.contact li i',
		'.agents-page .agents-wrapper .position',
		'.agent-single-page .position',
		'.submit-listings .wre-login-notification .cmb-th label',
		'#wre-listings-form-wrapper .cmb-multicheck-toggle',
		'.submit-listings .cmb2-metabox button.dashicons-before.dashicons-no-alt.cmb-remove-group-row:not([disabled])',
		'.wre-items li .title a:hover',
		'.wre-share-networks .share-icons i:hover',
		'.agents-page .agents-wrapper.agents-lists .wre-agent-details a:hover',
		'.agents-page .agents-wrapper .wre-social i:hover',
		'.agent-single-page .wre-single .agent-details-wrapper.wre-agent-details a:hover',
		'.agent-single-page .wre-social i:hover',
		'.compare-listings-page .wre-compare-wrapper .title:hover',
	);

	$css['global'][ realestate_implode( $elements ) ]['color'] = $primary_color_scheme;

	// WP Real Estate Background Color.
	$elements = array(
		'body.wp-rep #wre-search-form .button',
		'.wre-view-switcher > div.active',
		'body.wp-rep .wre-pagination ul li span.page-numbers.current',
		'body.wp-rep .wre-pagination ul li a.page-numbers:hover',
		'.wp-rep .wre-items .add-to-compare:hover',
		'body.wp-rep .wre-compare-listings a.compare-lists-btn',
		'body.single-listing #wre_contact_form .button-primary:hover',
		'.compare-listings-page .listing-column i::before',
		'.my-listings.wre .wre-my-listings-wrapper .wre-my-listings-icons li.wre-edit',
		'.my-listings .wre-add-new',
		'.submit-listings #wre-listings-form-wrapper .wre-login-notification .button',
		'.wre-remember-me #rememberme::after',
		'.submit-listings input[type=checkbox]::after',
		'.submit-listings #wre-listings-form-wrapper .cmb-row.cmb-repeatable-grouping button.button-secondary:hover',
		'.submit-listings #wre-listings-form-wrapper .cmb-add-row button:hover',
		'.submit-listings #wre-listings-form-wrapper input[type=submit]:hover',
		'.submit-listings #wre-listings-form-wrapper .cmb-td #wre-find:hover',
		'.submit-listings #wre-listings-form-wrapper .cmb-td #wre-reset:hover',
	);

	$css['global'][ realestate_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// WP Real Estate Hover Background Color.
	$hover_elements = array(
		'.wp-rep .wre-items .add-to-compare',
		'.my-listings.wre .wre-my-listings-wrapper .wre-my-listings-icons li.wre-delete',
		'.wre-packages-wrapper .wre-plan',
		'.wre-packages-wrapper .wre-price',
		'.wp-rep .wre-compare-listings a.compare-lists-btn:hover',
		'body.single-listing #wre_contact_form .button-primary',
		'.submit-listings #wre-listings-form-wrapper .wre-login-notification .button:hover',
		'.submit-listings #wre-listings-form-wrapper .wre-login-wrapper .button',
		'.submit-listings #wre-listings-form-wrapper .cmb-td #wre-find',
		'#wre-listings-form-wrapper .cmb-repeatable-group.repeatable .cmb-group-title',
		'.submit-listings #wre-listings-form-wrapper input[type=submit]',
		'.my-listings .wre-add-new:hover',
	);

	$css['global'][ realestate_implode( $hover_elements ) ]['background-color'] = $hover_color_scheme;

	// WP Real Estate Border Color.
	$hover_elements = array(
		'.wre-single .image-gallery .lSPager.lSGallery li.active',
		'.wre-single .image-gallery .lSPager.lSGallery li:hover',
	);

	$css['global'][ realestate_implode( $hover_elements ) ]['border-color'] = $primary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = realestate_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== realestate_get_settings( 'mts_social_button_position' ) && 'floating' === realestate_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			);

			$css['global'][ realestate_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ realestate_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ realestate_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ realestate_implode( $shareit_class ) ]['margin-right'] = realestate_px2rem( '100px' );
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_header( &$css ) {

	// Header.
	$header_class = array(
		'#header',
	);
	realestate_merge_value( $css['global'][ realestate_implode( $header_class ) ], Realestate_Sanitize::margin( realestate_get_settings( 'header_margin' ) ) );
	realestate_merge_value( $css['global'][ realestate_implode( $header_class ) ], Realestate_Sanitize::padding( realestate_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Realestate_Sanitize::border( realestate_get_settings( 'header_border' ) );
	$css['global'][ realestate_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation li a:hover']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'main_nav_hover_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'main_navigation_dropdown_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Nav Dropdown Background.
	$css['global']['.navigation ul ul']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'main_nav_dropdown_bg' ) );

	// Nav margin and Padding.
	realestate_merge_value( $css['global']['#primary-navigation'], Realestate_Sanitize::margin( realestate_get_settings( 'header_nav_margin' ) ) );
	realestate_merge_value( $css['global']['#primary-navigation'], Realestate_Sanitize::padding( realestate_get_settings( 'header_nav_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'header_contact_font' ) ) );

	// Header Ad.
	realestate_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Realestate_Sanitize::margin( realestate_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Realestate_Sanitize::color( realestate_get_settings( 'navigation_ad_background' ) );
}

/**
 * Header Slider Section
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_header_slider( &$css ) {

	$count          = 0;
	$slider_section = realestate_get_settings( 'header_slider' );
	$slider_list    = realestate_get_settings( 'slider_list' );

	if ( ! $slider_section || ! is_page_template( 'page-home.php' ) ) {
		return;
	}

	$css['global']['#site-header']['position'] = 'absolute';

	// Background.
	if ( ! empty( $slider_list ) && is_array( $slider_list ) ) {
		foreach ( $slider_list as $slide ) {

			$css['global'][ '.slide-' . ++$count . ' .overlay' ]['background-color'] = Realestate_Sanitize::color( $slide['slider_list_overlay'] );

			$css['global'][ '.slider-wrap.slide-' . $count ]['background-image'] = 'url(' . $slide['slider_list_image'] . ')';

		}
	}

	// Margin and Padding.
	realestate_merge_value( $css['global']['.slider-wrap'], Realestate_Sanitize::margin( realestate_get_settings( 'slider_margin' ) ) );
	realestate_merge_value( $css['global']['.slider-wrap'], Realestate_Sanitize::padding( realestate_get_settings( 'slider_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'slider_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'slider_content_font' ) ) );

}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Realestate_Sanitize::background( realestate_get_settings( 'social_styling_background' ) );
	realestate_merge_value( $css['global']['.shareit.floating'], Realestate_Sanitize::margin( realestate_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Realestate_Sanitize::border( realestate_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = realestate_get_settings( 'social_button_layout' );
	$social_button_position = realestate_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_sidebar_styling( &$css ) {

	// Sidebar.
	realestate_merge_value( $css['global']['.widget, .f-widget .widget'], Realestate_Sanitize::background( realestate_get_settings( 'sidebar_styling_background' ) ) );
	realestate_merge_value( $css['global']['.widget, .f-widget .widget'], Realestate_Sanitize::margin( realestate_get_settings( 'sidebar_styling_margin' ) ) );
	realestate_merge_value( $css['global']['.widget, .f-widget .widget'], Realestate_Sanitize::padding( realestate_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Realestate_Sanitize::border( realestate_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.widget, .f-widget .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Realestate_Sanitize::background( realestate_get_settings( 'sidebar_title_styling_background' ) );
	realestate_merge_value( $css['global'][ $sidebar_title ], Realestate_Sanitize::padding( realestate_get_settings( 'sidebar_title_styling_padding' ) ) );
	realestate_merge_value( $css['global'][ $sidebar_title ], Realestate_Sanitize::margin( realestate_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Realestate_Sanitize::border( realestate_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

	// Subscribe Widget.
	$css['global']['#sidebar .widget #wp-subscribe'] = Realestate_Sanitize::background( realestate_get_settings( 'subscribe_widget_background' ) );

	realestate_merge_value( $css['global']['#sidebar .widget #wp-subscribe'], Realestate_Sanitize::padding( realestate_get_settings( 'subscribe_widget_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'subscribe_widget_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'subscribe_widget_input_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'subscribe_widget_text_font' ) ) );

}

/**
 * HomePage Sections
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_home_sections( &$css ) {

	// Services Section.
	$count        = 0;
	$service_list = realestate_get_settings( 'services_list' );

	// Icon color.
	if ( ! empty( $service_list ) && is_array( $service_list ) ) {
		foreach ( $service_list as $service ) {

			$css['global'][ '.service-' . ++$count . ' .icon' ]['color'] = Realestate_Sanitize::color( $service['services_icon_color'] );

		}
	}

	// Background.
	$css['global']['.services-section'] = Realestate_Sanitize::background( realestate_get_settings( 'services_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.services-section'], Realestate_Sanitize::margin( realestate_get_settings( 'services_margin' ) ) );
	realestate_merge_value( $css['global']['.services-section'], Realestate_Sanitize::padding( realestate_get_settings( 'services_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'services_section_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'services_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'services_content_font' ) ) );

	// Counter Section.

	// Background.
	$css['global']['.counter-section'] = Realestate_Sanitize::background( realestate_get_settings( 'counter_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.counter-section'], Realestate_Sanitize::margin( realestate_get_settings( 'counter_margin' ) ) );
	realestate_merge_value( $css['global']['.counter-section'], Realestate_Sanitize::padding( realestate_get_settings( 'counter_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'counter_number_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'counter_text_font' ) ) );

	// Why Us Section.
	$count      = 0;
	$whyus_list = realestate_get_settings( 'whyus_list' );

	// Icon color.
	if ( ! empty( $whyus_list ) && is_array( $whyus_list ) ) {
		foreach ( $whyus_list as $whyus ) {

			++$count;

			$css['global'][ '.whyus-' . $count . ' .icon' ]['color'] = Realestate_Sanitize::color( $whyus['whyus_icon_color'] );

			$css['global'][ '.whyus-' . $count . ' .icon' ]['border-color'] = Realestate_Sanitize::color( $whyus['whyus_icon_border_color'] );

		}
	}

	// Background.
	$css['global']['.whyus-section'] = Realestate_Sanitize::background( realestate_get_settings( 'whyus_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.whyus-section'], Realestate_Sanitize::margin( realestate_get_settings( 'whyus_margin' ) ) );
	realestate_merge_value( $css['global']['.whyus-section'], Realestate_Sanitize::padding( realestate_get_settings( 'whyus_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'whyus_section_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'whyus_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'whyus_content_font' ) ) );

	// About Section.

	// Background.
	$css['global']['.about-section'] = Realestate_Sanitize::background( realestate_get_settings( 'about_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.about-section'], Realestate_Sanitize::margin( realestate_get_settings( 'about_margin' ) ) );
	realestate_merge_value( $css['global']['.about-section'], Realestate_Sanitize::padding( realestate_get_settings( 'about_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'about_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'about_content_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'about_quote_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'about_author_font' ) ) );

	// Testimonials Section.

	$count        = 0;
	$testimonials = realestate_get_settings( 'testimonials' );

	// Testimonial Background color.
	if ( ! empty( $testimonials ) && is_array( $testimonials ) ) {
		foreach ( $testimonials as $testimonial ) {

			$css['global'][ '.testimonial-' . ++$count ]['background-color'] = Realestate_Sanitize::color( $testimonial['testimonial_bg_color'] );

		}
	}

	// Section Background.
	$css['global']['.testimonials-section'] = Realestate_Sanitize::background( realestate_get_settings( 'testimonials_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.testimonials-section'], Realestate_Sanitize::margin( realestate_get_settings( 'testimonials_margin' ) ) );
	realestate_merge_value( $css['global']['.testimonials-section'], Realestate_Sanitize::padding( realestate_get_settings( 'testimonials_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'author_name_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'author_site_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'author_content_font' ) ) );

	// Clients Section.

	// Background.
	$css['global']['.clients-section'] = Realestate_Sanitize::background( realestate_get_settings( 'clients_background' ) );

	// Margin and Padding.
	realestate_merge_value( $css['global']['.clients-section'], Realestate_Sanitize::margin( realestate_get_settings( 'clients_margin' ) ) );
	realestate_merge_value( $css['global']['.clients-section'], Realestate_Sanitize::padding( realestate_get_settings( 'clients_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'clients_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'clients_content_font' ) ) );

	// Custom HTML.

	// Margin and Padding.
	realestate_merge_value( $css['global']['.html-section'], Realestate_Sanitize::margin( realestate_get_settings( 'html_margin' ) ) );
	realestate_merge_value( $css['global']['.html-section'], Realestate_Sanitize::padding( realestate_get_settings( 'html_padding' ) ) );

}

/**
 * Pages Title and Breadcrumb
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_page_titles( &$css ) {

	// Margin and Padding.
	realestate_merge_value( $css['global']['.pages-title-section'], Realestate_Sanitize::margin( realestate_get_settings( 'pages_title_margin' ) ) );
	realestate_merge_value( $css['global']['.pages-title-section'], Realestate_Sanitize::padding( realestate_get_settings( 'pages_title_padding' ) ) );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'breadcrumb_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'pages_title_font' ) ) );

	// Single Page
	$css['global']['.single-full-header .overlay']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'single_featured_overlay' ) );

	realestate_merge_value( $css['global']['.single-featured-content'], Realestate_Sanitize::padding( realestate_get_settings( 'single_featured_padding' ) ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_post_layouts( &$css ) {

	// Post Layouts.
	$features = realestate_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = realestate_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Realestate_Sanitize::background( realestate_get_settings( 'featured_category_title_background_' . $unique_id ) );
		realestate_merge_value( $css['global'][ $title_class ], Realestate_Sanitize::margin( realestate_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		realestate_merge_value( $css['global'][ $title_class ], Realestate_Sanitize::padding( realestate_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Realestate_Sanitize::border( realestate_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Realestate_Sanitize::border( realestate_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'meta_info_font_' . $unique_id ) ) );

		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'post_title_font_' . $unique_id ) ) );
		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		// All Posts Margin and Padding.
		realestate_merge_value( $css['global'][ $post_class ], Realestate_Sanitize::margin( realestate_get_settings( 'post_margin_' . $unique_id ) ) );
		realestate_merge_value( $css['global'][ $post_class ], Realestate_Sanitize::padding( realestate_get_settings( 'post_padding_' . $unique_id ) ) );

		if ( 'layout-full' === $posts_layout ) {
			$css['global'][ '.layout-' . $unique_id . ' .wrapper' ]['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'full_post_overlay_' . $unique_id ) );
		}

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
	);
	realestate_merge_value( $css['global'][ realestate_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Realestate_Sanitize::margin( realestate_get_settings( 'mts_pagenavigation_margin' ) ) );
	if ( '2' !== realestate_get_settings( 'mts_pagenavigation_type' ) ) {

		$css['global'][ realestate_implode( $pagination_class ) ]['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'mts_pagenavigation_bgcolor' ) );

		$css['global'][ realestate_implode( $pagination_class_active ) ]['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

		$css['global'][ realestate_implode( $pagination_class ) ]['color'] = Realestate_Sanitize::color( realestate_get_settings( 'mts_pagenavigation_color' ) );

		$css['global'][ realestate_implode( $pagination_class_active ) ]['color'] = Realestate_Sanitize::color( realestate_get_settings( 'mts_pagenavigation_hover_color' ) );

		realestate_merge_value( $css['global'][ realestate_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Realestate_Sanitize::padding( realestate_get_settings( 'mts_pagenavigation_padding' ) ) );
	} else {
		$css['global']['#load-posts a']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'load_more_bgcolor' ) );

		$css['global']['#load-posts a:hover']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'load_more_hover_bgcolor' ) );

		$css['global']['#load-posts a']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'load_more_color' ) );

		$css['global']['#load-posts a:hover']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'load_more_hover_color' ) );

		realestate_merge_value( $css['global']['#load-posts a'], Realestate_Sanitize::padding( realestate_get_settings( 'load_more_padding' ) ) );
	}

	$border_radius_class   = $pagination_class;
	$border_radius_class[] = '#load-posts a';

	// Border radius.
	$css['global'][ realestate_implode( $border_radius_class ) ]['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	$css['global'][ realestate_implode( $pagination_class_active ) ]['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = Realestate_Sanitize::border( realestate_get_settings( 'pagenavigation_border' ) );
	$css['global'][ realestate_implode( array_merge( $pagination_class_active, $border_radius_class ) ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = realestate_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = realestate_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ realestate_implode( $page_classes ) ] = Realestate_Sanitize::background( realestate_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	realestate_merge_value( $css['global']['.article'], Realestate_Sanitize::margin( realestate_get_settings( 'mts_single_styling_margin' ) ) );
	realestate_merge_value( $css['global'][ realestate_implode( $page_classes ) ], Realestate_Sanitize::padding( realestate_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Realestate_Sanitize::border( realestate_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'mts_single_meta_info_font' ) ) );

	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'tags_bgcolor' ) );

	// Related Posts.
	$css['global']['.related-posts'] = Realestate_Sanitize::background( realestate_get_settings( 'related_posts_background' ) );

	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'related_posts_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'related_posts_meta_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'related_posts_excerpt_font' ) ) );

	realestate_merge_value( $css['global']['.related-posts'], Realestate_Sanitize::margin( realestate_get_settings( 'related_posts_margin' ) ) );
	realestate_merge_value( $css['global']['.related-posts'], Realestate_Sanitize::padding( realestate_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Realestate_Sanitize::border( realestate_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Realestate_Sanitize::background( realestate_get_settings( 'related_article_background' ) );
	realestate_merge_value( $css['global']['.related-posts article'], Realestate_Sanitize::padding( realestate_get_settings( 'related_article_padding' ) ) );
	realestate_merge_value( $css['global']['.related-posts article header'], Realestate_Sanitize::padding( realestate_get_settings( 'related_article_text_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Realestate_Sanitize::background( realestate_get_settings( 'single_subscribe_background' ) );
	realestate_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Realestate_Sanitize::margin( realestate_get_settings( 'single_subscribe_margin' ) ) );
	realestate_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Realestate_Sanitize::padding( realestate_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Realestate_Sanitize::border( realestate_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ realestate_implode( $subscribe_input_class ) ]['height'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['line-height'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ realestate_implode( $subscribe_input_class ) ]['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Realestate_Sanitize::border( realestate_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ realestate_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Realestate_Sanitize::color( realestate_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Realestate_Sanitize::border( realestate_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	realestate_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Realestate_Sanitize::padding( realestate_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Realestate_Sanitize::background( realestate_get_settings( 'authorbox_background' ) );

	realestate_merge_value( $css['global']['.postauthor'], Realestate_Sanitize::margin( realestate_get_settings( 'authorbox_margin' ) ) );

	realestate_merge_value( $css['global']['.postauthor'], Realestate_Sanitize::padding( realestate_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'authorbox_border_radius' ) . 'px' );

	// Border.
	realestate_merge_value( $css['global']['.postauthor'], Realestate_Sanitize::border2( realestate_get_settings( 'authorbox_border' ) ) );

	// Author image.
	realestate_merge_value( $css['global']['.postauthor img'], Realestate_Sanitize::margin( realestate_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = realestate_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ realestate_implode( $titles_class ) ] = Realestate_Sanitize::background( realestate_get_settings( 'single_title_background' ) );
	realestate_merge_value( $css['global'][ realestate_implode( $titles_class ) ], Realestate_Sanitize::padding( realestate_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Realestate_Sanitize::border( realestate_get_settings( 'single_title_border' ) );
	$css['global'][ realestate_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ realestate_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ realestate_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ realestate_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ realestate_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ realestate_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.
	realestate_merge_value( $css['global']['#comments'], Realestate_Sanitize::margin( realestate_get_settings( 'comments_margin' ) ) );
	realestate_merge_value( $css['global']['#comments'], Realestate_Sanitize::padding( realestate_get_settings( 'comments_padding' ) ) );
	realestate_merge_value( $css['global']['#comments li'], Realestate_Sanitize::margin( realestate_get_settings( 'comments_list_margin' ) ) );
	realestate_merge_value( $css['global']['#comments li'], Realestate_Sanitize::padding( realestate_get_settings( 'comments_list_padding' ) ) );
	realestate_merge_value( $css['global']['#comments .avatar'], Realestate_Sanitize::margin( realestate_get_settings( 'comments_list_image_margin' ) ) );

	// Author Comment.
	realestate_merge_value( $css['global']['#comments li.bypostauthor'], Realestate_Sanitize::margin( realestate_get_settings( 'comments_list_author_margin' ) ) );
	realestate_merge_value( $css['global']['#comments li.bypostauthor'], Realestate_Sanitize::padding( realestate_get_settings( 'comments_list_author_padding' ) ) );
	$css['global']['#comments li.bypostauthor']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'author_comment_bg' ) );

	// Comment list.
	// Border.
	$single_titles_border = Realestate_Sanitize::border( realestate_get_settings( 'comments_list_border' ) );
	$css['global']['#comments li'][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	$css['global']['#comments ul.children']['border-top'] = $single_titles_border ['value'];

	$css['global']['#comments .avatar']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'comments_list_image_border_radius' ) . 'px' );

	// Typography.
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'comments_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'comments_meta_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'comments_text_font' ) ) );

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_copyrights( &$css ) {

	// copyrights border.
	$copyrights_border = Realestate_Sanitize::border( realestate_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_footer( &$css ) {

	// Footer.
	if ( realestate_get_settings( 'mts_top_footer' ) ) {
		realestate_merge_value( $css['global']['#site-footer'], Realestate_Sanitize::margin( realestate_get_settings( 'mts_top_footer_margin' ) ) );
		realestate_merge_value( $css['global']['#site-footer'], Realestate_Sanitize::padding( realestate_get_settings( 'mts_top_footer_padding' ) ) );
	}

	// Copyrights.
	realestate_merge_value( $css['global']['.copyrights'], Realestate_Sanitize::margin( realestate_get_settings( 'copyrights_margin' ) ) );
	realestate_merge_value( $css['global']['.copyrights'], Realestate_Sanitize::padding( realestate_get_settings( 'copyrights_padding' ) ) );

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_archive_post( &$css ) {

	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_post_title_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_post_excerpt_font' ) ) );
	realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'archive_meta_info_font' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function realestate_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Realestate_Sanitize::padding( realestate_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Logo.
	$show_logo       = realestate_get_settings( 'hide_logo' );
	$realestate_logo = wp_get_attachment_url( realestate_get_settings( 'mts_logo' ) );
	$logo_width      = realestate_get_settings( 'logo_width' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}
	if ( ! empty( $realestate_logo ) ) {
		$css['global']['.logo-wrap']['max-width'] = $logo_width . 'px';
	}

	// Back to top.
	$css['global']['#move-to-top']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'top_button_background' ) );

	$css['global']['#move-to-top:hover']['background-color'] = Realestate_Sanitize::color( realestate_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Realestate_Sanitize::border( realestate_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Realestate_Sanitize::size( realestate_get_settings( 'top_button_font_size' ) . 'px' );
	realestate_merge_value( $css['global']['#move-to-top'], Realestate_Sanitize::padding( realestate_get_settings( 'top_button_padding' ) ) );
	$top_button_position = realestate_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Realestate_Sanitize::size( realestate_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']       = Realestate_Sanitize::color( realestate_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color'] = Realestate_Sanitize::color( realestate_get_settings( 'top_button_color_hover' ) );

	$css['global']['#move-to-top:hover']['border-color'] = Realestate_Sanitize::color( realestate_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === realestate_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

	/**
	 * WP Real Estate Pro Settings
	 *
	 * @param array $css Array of dynamic CSS.
	 */
	function realestate_wprep_sections( &$css ) {

		// Page Background
		$css['global']['html body.wp-rep'] = Realestate_Sanitize::background( realestate_get_settings( 'wprep_background' ) );

		// Sidebar
		$css['global']['.wre-sidebar .wre-widget'] = Realestate_Sanitize::background( realestate_get_settings( 'wprep_sidebar_background' ) );

		realestate_merge_value( $css['global']['.wre-sidebar .wre-widget'], Realestate_Sanitize::padding( realestate_get_settings( 'wprep_sidebar_padding' ) ) );

		// Packages
		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'packages_title_font' ) ) );
		realestate_map_css_selectors( $css['global'], Realestate_Sanitize::typography( realestate_get_settings( 'packages_price_font' ) ) );

	}

}
